FloatingNavBarItem class

FloatingNavBarItem

FloatingNavbarItem Base class for the bottom navigation bar items

Constructors

FloatingNavBarItem({IconData? iconData, bool useImageIcon = false, ImageIcon? icon, required String title, required Widget page})

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ ImageIcon?
getter/setter pair
iconData ↔ IconData?
IconData to display on the navbar e.g. Icons.home
getter/setter pair
page ↔ Widget
The page that corresponds to this item
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
Title can used instead of the dot indicator
getter/setter pair
useImageIcon ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited